@@ -26,16 +26,18 @@ THE SOFTWARE.
 """)
 
 __author__ = "Matthew Marshall <matthew@matthewmarshall.org>"
-__version__ = "0.7.5b"
+__version__ = "0.8"
 
 import heapq
 import os.path
+import sys
 
 from rabbyt._rabbyt import *
 from rabbyt.sprites import *
 from rabbyt.anims import *
 import rabbyt.collisions
-import rabbyt.dummy_physics as physics
+
+from warnings import warn
 
 
 class Scheduler(object):
@@ -83,19 +85,26 @@ scheduler = Scheduler()
 
 def init_display(size=(640, 480), flags = 0):
     """
-    init_display(size=(640, 480), flags = 0)
+    In an ongoing attempt at cleaning up rabbyt, init_display has been
+    deprecated and will be removed in a future version.  You can achive the
+    same result by doing this:
 
-    This is a small shortcut to create a pygame window, set the viewport, and
-    set the opengl attributes need for rabbyt.
-
-    ``flags`` is passed to ``pygame.display.set_mode()`` (OR'ed with
-    ``pygame.OPENGL`` and ``pygame.DOUBLEBUF``.)
-
-    The pygame surface returned by ``pygame.display.set_mode()`` is returned.
-
-    This function depends on pygame.
+    pygame.init()
+    pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
+    rabbyt.set_viewport(size)
+    rabbyt.set_default_attribs()
     """
-    import pygame
+    warn("""
+        In an ongoing attempt at cleaning up rabbyt, init_display has been
+        deprecated and will be removed in a future version.  You can achive the
+        same result by doing this:
+
+        pygame.init()
+        pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
+        rabbyt.set_viewport(size)
+        rabbyt.set_default_attribs()
+        """, stacklevel=2)
+    pygame = __import__("pygame", {},{},[])
     pygame.init()
     surface = pygame.display.set_mode(size, pygame.OPENGL |
             pygame.DOUBLEBUF | flags)
@@ -119,7 +128,7 @@ def pygame_load_texture(filename, filter=True, mipmap=True):
     first, then ``rabbyt.data_directory`` is searched for the file.
     """
     if filename not in _texture_cache:
-        import pygame
+        pygame = __import__("pygame", {},{},[])
         if os.path.exists(filename):
             img = pygame.image.load(filename)
         else:
@@ -138,7 +147,7 @@ def pyglet_load_texture(filename):
     (This is meant to be used with ``set_load_texture_file_hook``.)
     """
     if filename not in _texture_cache:
-        from pyglet import image
+        image = __import__("pyglet", {},{},["image"]).image
         if os.path.exists(filename):
             img = image.load(filename)
         else:
@@ -161,35 +170,36 @@ def autodetect_load_texture(filename):
 
     This is the default function for loading textures.
     """
-    func = pygame_load_texture
-    try:
-        from pyglet.gl import get_current_context
+
+    pyglet = sys.modules.get("pyglet", None)
+    pygame = sys.modules.get("pygame", None)
+
+    if pyglet and pygame:
+        # Both pygame and pyglet have been loaded, so we check if a pyglet
+        # context has been created.
+        get_current_context = __import__("pyglet.gl",
+                {},{},['get_current_context']).get_current_context
         if get_current_context():
-            # There is a pyglet context loaded; let's use pyglet's texture
-            # loading.
             func = pyglet_load_texture
         else:
-            # If there isn't a context, the user might be trying to load
-            # texture before creating the window.  If this is the case,
-            # we don't want to give a confusing ImportError if pygame is
-            # not installed.
-            try:
-                import pygame
-            except ImportError:
-                # Go ahead and use pyglet. It'll give a nice error.
-                func =  pyglet_load_texture
-    except ImportError:
-        pass
+            func = pygame_load_texture
+    elif pyglet:
+        func = pyglet_load_texture
+    else:
+        func = pygame_load_texture
 
     set_load_texture_file_hook(func)
     return func(filename)
 set_load_texture_file_hook(autodetect_load_texture)
 
-__all__ = __docs_all__ = ('anims collisions fonts sprites vertexarrays '
+__all__ = __docs_all__ = ('sprites anims primitives collisions '
 'Scheduler '
-'init_display set_viewport set_default_attribs set_gl_color clear '
+'set_viewport set_default_attribs clear '
 'get_gl_vendor '
 'render_unsorted '
 'load_texture update_texture unload_texture '
 'autodetect_load_texture pyglet_load_texture pygame_load_texture '
-'set_load_texture_file_hook ').split()
\ No newline at end of file
+'set_load_texture_file_hook ').split()
+# Some people might be using from rabbyt import *.  I might as well keep
+# init_display there for now.
+__all__.append("init_display")
\ No newline at end of file
